package backend

import (
	"kpt-pasture/model"

	pasturePb "gitee.com/xuyiping_admin/go_proto/proto/go/backend/cow"
	"gitee.com/xuyiping_admin/pkg/logger/zaplog"
	"go.uber.org/zap"
)

func (s *StoreEntry) LactEnumList(isAll string) []*pasturePb.ConfigOptionsList {
	configOptions := make([]*pasturePb.ConfigOptionsList, 0)
	if isAll == model.IsAllYes {
		configOptions = append(configOptions, &pasturePb.ConfigOptionsList{
			Value:    int32(0),
			Label:    "全部",
			Disabled: true,
		})
	}
	configOptions = append(configOptions, &pasturePb.ConfigOptionsList{
		Value:    int32(1),
		Label:    "1",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(2),
		Label:    "2",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(3),
		Label:    "3",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(4),
		Label:    ">3",
		Disabled: true,
	})
	return configOptions
}

func (s *StoreEntry) DiseaseAnalysisMethodEnumList(isAll string) []*pasturePb.ConfigOptionsList {
	configOptions := make([]*pasturePb.ConfigOptionsList, 0)
	if isAll == model.IsAllYes {
		configOptions = append(configOptions, &pasturePb.ConfigOptionsList{
			Value:    int32(pasturePb.DiseaseAnalysisMethod_Invalid),
			Label:    "全部",
			Disabled: true,
		})
	}
	configOptions = append(configOptions, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.DiseaseAnalysisMethod_Months),
		Label:    "按月份",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.DiseaseAnalysisMethod_Disease_Category),
		Label:    "疾病分类",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.DiseaseAnalysisMethod_Disease),
		Label:    "疾病名称",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.DiseaseAnalysisMethod_Operator),
		Label:    "兽医",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.DiseaseAnalysisMethod_Prescription),
		Label:    "处方",
		Disabled: true,
	})
	return configOptions
}

func (s *StoreEntry) diseaseTypeEnumList(isAll string) []*pasturePb.ConfigOptionsList {
	configDiseaseTypeList := make([]*model.ConfigDiseaseType, 0)
	configOptionsList := make([]*pasturePb.ConfigOptionsList, 0)
	if err := s.DB.Where("is_show = ?", pasturePb.IsShow_Ok).Find(&configDiseaseTypeList).Error; err != nil {
		zaplog.Error("diseaseTypeEnumList", zap.Any("Find", err))
	}

	for _, v := range configDiseaseTypeList {
		configOptionsList = append(configOptionsList, &pasturePb.ConfigOptionsList{
			Value:    int32(v.Id),
			Label:    v.Name,
			Disabled: true,
		})
	}
	return configOptionsList
}

func (s *StoreEntry) SingleFactorAnalysisMethodEnumList(isAll string) []*pasturePb.ConfigOptionsList {
	configOptions := make([]*pasturePb.ConfigOptionsList, 0)
	configOptions = append(configOptions, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.SingleFactorAnalysisMethod_Cycle),
		Label:    "按周期分析",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.SingleFactorAnalysisMethod_Months),
		Label:    "按月份分析",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.SingleFactorAnalysisMethod_Mating_Times),
		Label:    "按配种次数分析",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.SingleFactorAnalysisMethod_Breeding_Method),
		Label:    "按配种方式分析",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.SingleFactorAnalysisMethod_Breeding_Company),
		Label:    "按育种公司分析",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.SingleFactorAnalysisMethod_Operation),
		Label:    "按兽医人员分析",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.SingleFactorAnalysisMethod_Mating_Interval),
		Label:    "按配种间隔分析",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.SingleFactorAnalysisMethod_Bull),
		Label:    "按公牛号分析",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.SingleFactorAnalysisMethod_Breeding_Cycle),
		Label:    "按配种周期分析",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.SingleFactorAnalysisMethod_Week),
		Label:    "按星期分析",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.SingleFactorAnalysisMethod_Lact),
		Label:    "按胎次分析",
		Disabled: true,
	})
	return configOptions
}

func (s *StoreEntry) LactIntervalSymbolEnumList(isAll string) []*pasturePb.ConfigOptionsList {
	configOptions := make([]*pasturePb.ConfigOptionsList, 0)
	configOptions = append(configOptions, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.LactIntervalSymbol_Less_Than),
		Label:    "<",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.LactIntervalSymbol_Less_Than_Or_Equal_To),
		Label:    "<=",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.LactIntervalSymbol_Greater_Than),
		Label:    ">",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.LactIntervalSymbol_Greater_Than_Or_Equal_To),
		Label:    ">=",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.LactIntervalSymbol_Equal_To),
		Label:    "=",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.LactIntervalSymbol_Not_Equal_To),
		Label:    "!=",
		Disabled: true,
	}, &pasturePb.ConfigOptionsList{
		Value:    int32(pasturePb.LactIntervalSymbol_Between),
		Label:    "区间",
		Disabled: true,
	})
	return configOptions
}
